==> fannypack-2.2.0.tgz: package/es/Column/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n  '], ['\n    margin-left: auto;\n  ']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n    margin-right: auto;\n  '], ['\n    margin-left: auto;\n    margin-right: auto;\n  ']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n    margin-right: auto;\n  '], ['\n    margin-right: auto;\n  ']),
    _templateObject4 = _taggedTemplateLiteralLoose(['\n      @media (max-width: ', 'px) {\n        flex: none;\n        width: 100%;\n      }\n    '], ['\n      @media (max-width: ', 'px) {\n        flex: none;\n        width: 100%;\n      }\n    ']),
    _templateObject5 = _taggedTemplateLiteralLoose(['\n      flex: none;\n      width: ', ';\n    '], ['\n      flex: none;\n      width: ', ';\n    ']),
    _templateObject6 = _taggedTemplateLiteralLoose(['\n        @media (max-width: ', 'px) {\n          ', ';\n        }\n      '], ['\n        @media (max-width: ', 'px) {\n          ', ';\n        }\n      ']),
    _templateObject7 = _taggedTemplateLiteralLoose(['\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n  '], ['\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n  ']),
    _templateObject8 = _taggedTemplateLiteralLoose(['\n        @media (max-width: ', 'px) {\n          width: 100%;\n        }\n      '], ['\n        @media (max-width: ', 'px) {\n          width: 100%;\n        }\n      ']),
    _templateObject9 = _taggedTemplateLiteralLoose(['\n      margin-left: ', ';\n    '], ['\n      margin-left: ', ';\n    ']),
    _templateObject10 = _taggedTemplateLiteralLoose(['\n      ', ' /**/\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n    '], ['\n      ', ' /**/\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n    ']),
    _templateObject11 = _taggedTemplateLiteralLoose(['\n          @media (max-width: ', 'px) {\n            margin-left: 0;\n          }\n        '], ['\n          @media (max-width: ', 'px) {\n            margin-left: 0;\n          }\n        ']),
    _templateObject12 = _taggedTemplateLiteralLoose(['\n  flex: 1;\n  max-width: 100%;\n  ', ';\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  flex: 1;\n  max-width: 100%;\n  ', ';\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']),
    _templateObject13 = _taggedTemplateLiteralLoose(['\n          padding: ', 'rem;\n        '], ['\n          padding: ', 'rem;\n        ']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import { css } from 'reakit/styled';
import styled from 'reakit/styled';
import Box from 'reakit/Box';
import { theme } from 'styled-tools';

var marginAutoOffsets = {
  left: css(_templateObject),
  both: css(_templateObject2),
  right: css(_templateObject3)
};

var getWidth = function getWidth(spread) {
  return spread / 12 * 100 + '%';
};

var getSpreadAttributes = function getSpreadAttributes(props) {
  var minBreakpoint = props.minBreakpoint,
      spread = props.spread,
      spreadMobile = props.spreadMobile,
      spreadTablet = props.spreadTablet,
      spreadDesktop = props.spreadDesktop,
      spreadWidescreen = props.spreadWidescreen,
      spreadFullHD = props.spreadFullHD;

  if (!minBreakpoint && !spread && !spreadMobile && !spreadTablet && !spreadDesktop && !spreadWidescreen && !spreadFullHD) {
    return css(_templateObject4, theme('layout.tabletBreakpoint'));
  }

  var getAttributes = function getAttributes(_ref) {
    var breakpoint = _ref.breakpoint,
        spread = _ref.spread;

    var attributes = css(_templateObject5, getWidth(spread));
    if (!spread) return null;
    if (breakpoint) {
      return css(_templateObject6, theme('layout.' + breakpoint), attributes);
    }
    return attributes;
  };

  return css(_templateObject7, getAttributes({ spread: spread }), getAttributes({ spread: spreadFullHD, breakpoint: 'fullHDBreakpoint' }), getAttributes({ spread: spreadWidescreen, breakpoint: 'widescreenBreakpoint' }), getAttributes({ spread: spreadDesktop, breakpoint: 'desktopBreakpoint' }), minBreakpoint !== 'tablet' && minBreakpoint !== 'mobile' && !spreadTablet && !spreadMobile && css(_templateObject8, theme('layout.tabletBreakpoint')), getAttributes({ spread: spreadTablet, breakpoint: 'tabletBreakpoint' }), minBreakpoint !== 'mobile' && !spreadMobile && css(_templateObject8, theme('layout.mobileBreakpoint')), getAttributes({ spread: spreadMobile, breakpoint: 'mobileBreakpoint' }));
};

var getSpreadOffsetAttributes = function getSpreadOffsetAttributes(props) {
  var spreadOffset = props.spreadOffset,
      spreadMobileOffset = props.spreadMobileOffset,
      spreadTabletOffset = props.spreadTabletOffset,
      spreadDesktopOffset = props.spreadDesktopOffset,
      spreadWidescreenOffset = props.spreadWidescreenOffset,
      spreadFullHDOffset = props.spreadFullHDOffset;

  if (!spreadOffset && !spreadMobileOffset && !spreadTabletOffset && !spreadDesktopOffset && !spreadWidescreenOffset && !spreadFullHDOffset) {
    return null;
  }

  var getAttributes = function getAttributes(_ref2) {
    var breakpoint = _ref2.breakpoint,
        spreadOffset = _ref2.spreadOffset;

    var attributes = css(_templateObject9, getWidth(spreadOffset));
    if (!spreadOffset) return null;
    if (breakpoint) {
      return css(_templateObject6, theme('layout.' + breakpoint), attributes);
    }
    return attributes;
  };

  if (typeof spreadOffset === 'number') {
    return css(_templateObject10, getAttributes({ spreadOffset: spreadOffset }), getAttributes({
      spreadOffset: spreadFullHDOffset,
      breakpoint: 'fullHDBreakpoint'
    }), getAttributes({ spreadOffset: spreadWidescreenOffset, breakpoint: 'widescreenBreakpoint' }), getAttributes({ spreadOffset: spreadDesktopOffset, breakpoint: 'desktopBreakpoint' }), !spreadTabletOffset && !spreadMobileOffset && css(_templateObject11, theme('layout.tabletBreakpoint')), getAttributes({ spreadOffset: spreadTabletOffset, breakpoint: 'tabletBreakpoint' }), !spreadMobileOffset && css(_templateObject11, theme('layout.mobileBreakpoint')), getAttributes({ spreadOffset: spreadMobileOffset, breakpoint: 'mobileBreakpoint' }));
  }
  return marginAutoOffsets[spreadOffset];
};

var Column = styled(Box)(_templateObject12, function (props) {
  return !props.isGapless ? css(_templateObject13, theme('layout.gapFactor')) : null;
}, getSpreadAttributes, getSpreadOffsetAttributes, theme('Column.base'));

export default Column;

==> fannypack-2.8.0.tgz: package/es/Column/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n  '], ['\n    margin-left: auto;\n  ']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n    margin-right: auto;\n  '], ['\n    margin-left: auto;\n    margin-right: auto;\n  ']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n    margin-right: auto;\n  '], ['\n    margin-right: auto;\n  ']),
    _templateObject4 = _taggedTemplateLiteralLoose(['\n      @media (max-width: ', 'px) {\n        flex: none;\n        width: 100%;\n      }\n    '], ['\n      @media (max-width: ', 'px) {\n        flex: none;\n        width: 100%;\n      }\n    ']),
    _templateObject5 = _taggedTemplateLiteralLoose(['\n      flex: none;\n      width: ', ';\n    '], ['\n      flex: none;\n      width: ', ';\n    ']),
    _templateObject6 = _taggedTemplateLiteralLoose(['\n        @media (max-width: ', 'px) {\n          ', ';\n        }\n      '], ['\n        @media (max-width: ', 'px) {\n          ', ';\n        }\n      ']),
    _templateObject7 = _taggedTemplateLiteralLoose(['\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n  '], ['\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n    ', ';\n  ']),
    _templateObject8 = _taggedTemplateLiteralLoose(['\n        @media (max-width: ', 'px) {\n          width: 100%;\n        }\n      '], ['\n        @media (max-width: ', 'px) {\n          width: 100%;\n        }\n      ']),
    _templateObject9 = _taggedTemplateLiteralLoose(['\n      margin-left: ', ';\n    '], ['\n      margin-left: ', ';\n    ']),
    _templateObject10 = _taggedTemplateLiteralLoose(['\n      ', ' /**/\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n    '], ['\n      ', ' /**/\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n      ', ';\n    ']),
    _templateObject11 = _taggedTemplateLiteralLoose(['\n          @media (max-width: ', 'px) {\n            margin-left: 0;\n          }\n        '], ['\n          @media (max-width: ', 'px) {\n            margin-left: 0;\n          }\n        ']),
    _templateObject12 = _taggedTemplateLiteralLoose(['\n  flex: 1;\n  max-width: 100%;\n  ', ';\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n'], ['\n  flex: 1;\n  max-width: 100%;\n  ', ';\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n\n  & {\n    ', ';\n  }\n']),
    _templateObject13 = _taggedTemplateLiteralLoose(['\n          padding: ', 'rem;\n        '], ['\n          padding: ', 'rem;\n        ']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import { css } from 'reakit/styled';
import styled from 'reakit/styled';
import Box from 'reakit/Box';
import { theme } from 'styled-tools';

var marginAutoOffsets = {
  left: css(_templateObject),
  both: css(_templateObject2),
  right: css(_templateObject3)
};

var getWidth = function getWidth(spread) {
  return spread / 12 * 100 + '%';
};

var getSpreadProperties = function getSpreadProperties(props) {
  var minBreakpoint = props.minBreakpoint,
      spread = props.spread,
      spreadMobile = props.spreadMobile,
      spreadTablet = props.spreadTablet,
      spreadDesktop = props.spreadDesktop,
      spreadWidescreen = props.spreadWidescreen,
      spreadFullHD = props.spreadFullHD;

  if (!minBreakpoint && !spread && !spreadMobile && !spreadTablet && !spreadDesktop && !spreadWidescreen && !spreadFullHD) {
    return css(_templateObject4, theme('layout.tabletBreakpoint'));
  }

  var getProperties = function getProperties(_ref) {
    var breakpoint = _ref.breakpoint,
        spread = _ref.spread;

    var properties = css(_templateObject5, getWidth(spread));
    if (!spread) return null;
    if (breakpoint) {
      return css(_templateObject6, theme('layout.' + breakpoint), properties);
    }
    return properties;
  };

  return css(_templateObject7, getProperties({ spread: spread }), getProperties({ spread: spreadFullHD, breakpoint: 'fullHDBreakpoint' }), getProperties({ spread: spreadWidescreen, breakpoint: 'widescreenBreakpoint' }), getProperties({ spread: spreadDesktop, breakpoint: 'desktopBreakpoint' }), minBreakpoint !== 'tablet' && minBreakpoint !== 'mobile' && !spreadTablet && !spreadMobile && css(_templateObject8, theme('layout.tabletBreakpoint')), getProperties({ spread: spreadTablet, breakpoint: 'tabletBreakpoint' }), minBreakpoint !== 'mobile' && !spreadMobile && css(_templateObject8, theme('layout.mobileBreakpoint')), getProperties({ spread: spreadMobile, breakpoint: 'mobileBreakpoint' }));
};

var getSpreadOffsetProperties = function getSpreadOffsetProperties(props) {
  var spreadOffset = props.spreadOffset,
      spreadMobileOffset = props.spreadMobileOffset,
      spreadTabletOffset = props.spreadTabletOffset,
      spreadDesktopOffset = props.spreadDesktopOffset,
      spreadWidescreenOffset = props.spreadWidescreenOffset,
      spreadFullHDOffset = props.spreadFullHDOffset;

  if (!spreadOffset && !spreadMobileOffset && !spreadTabletOffset && !spreadDesktopOffset && !spreadWidescreenOffset && !spreadFullHDOffset) {
    return null;
  }

  var getProperties = function getProperties(_ref2) {
    var breakpoint = _ref2.breakpoint,
        spreadOffset = _ref2.spreadOffset;

    var properties = css(_templateObject9, getWidth(spreadOffset));
    if (!spreadOffset) return null;
    if (breakpoint) {
      return css(_templateObject6, theme('layout.' + breakpoint), properties);
    }
    return properties;
  };

  if (typeof spreadOffset === 'number') {
    return css(_templateObject10, getProperties({ spreadOffset: spreadOffset }), getProperties({
      spreadOffset: spreadFullHDOffset,
      breakpoint: 'fullHDBreakpoint'
    }), getProperties({ spreadOffset: spreadWidescreenOffset, breakpoint: 'widescreenBreakpoint' }), getProperties({ spreadOffset: spreadDesktopOffset, breakpoint: 'desktopBreakpoint' }), !spreadTabletOffset && !spreadMobileOffset && css(_templateObject11, theme('layout.tabletBreakpoint')), getProperties({ spreadOffset: spreadTabletOffset, breakpoint: 'tabletBreakpoint' }), !spreadMobileOffset && css(_templateObject11, theme('layout.mobileBreakpoint')), getProperties({ spreadOffset: spreadMobileOffset, breakpoint: 'mobileBreakpoint' }));
  }
  return marginAutoOffsets[spreadOffset];
};

var Column = styled(Box)(_templateObject12, function (props) {
  return !props.isGapless ? css(_templateObject13, theme('layout.gapFactor')) : null;
}, getSpreadProperties, getSpreadOffsetProperties, theme('Column.base'));

export default Column;
